package Data::Password::zxcvbn::AdjacencyGraph::German;
use strict;
use warnings;
# VERSION
# ABSTRACT: adjacency graphs for common German keyboards

=head1 DESCRIPTION

This is a data file used by L<<
C<Data::Password::zxcvbn::Match::Spatial> >>, and is generated by the
L<<
C<build-keyboard-adjacency-graphs>|https://bitbucket.org/broadbean/p5-data-password-zxcvbn-german/src/master/maint/build-keyboard-adjacency-graphs
>> program when building the distribution.


=cut

our %graphs = (
  'qwertz_t1' => {
    'average_degree' => '4.58620689655172',
    'keys' => {
      '!' => [
        '^^',
        undef,
        undef,
        '2"',
        'qQ',
        undef,
      ],
      '"' => [
        '1!',
        undef,
        undef,
        '33',
        'wW',
        'qQ',
      ],
      '#' => [
        undef,
        '+*',
        undef,
        undef,
        undef,
        undef,
      ],
      '$' => [
        '33',
        undef,
        undef,
        '5%',
        'rR',
        'eE',
      ],
      '%' => [
        '4$',
        undef,
        undef,
        '6&',
        'tT',
        'rR',
      ],
      '&' => [
        '5%',
        undef,
        undef,
        '7/',
        'zZ',
        'tT',
      ],
      '\'' => [
        '\\?',
        undef,
        undef,
        undef,
        '+*',
        undef,
        undef,
        '+*',
        undef,
        undef,
        undef,
        undef,
      ],
      '(' => [
        '7/',
        undef,
        undef,
        '9)',
        'iI',
        'uU',
      ],
      ')' => [
        '8(',
        undef,
        undef,
        '0=',
        'oO',
        'iI',
      ],
      '*' => [
        undef,
        '`\'',
        undef,
        undef,
        '#\'',
        undef,
      ],
      '+' => [
        undef,
        '`\'',
        undef,
        undef,
        '#\'',
        undef,
      ],
      ',' => [
        'mM',
        'kK',
        'lL',
        '.:',
        undef,
        undef,
      ],
      '-' => [
        '.:',
        'oO',
        undef,
        undef,
        undef,
        undef,
      ],
      '.' => [
        ',;',
        'lL',
        'oO',
        '-_',
        undef,
        undef,
      ],
      '/' => [
        '6&',
        undef,
        undef,
        '8(',
        'uU',
        'zZ',
      ],
      '0' => [
        '9)',
        undef,
        undef,
        '\\?',
        'pP',
        'oO',
      ],
      '1' => [
        '^^',
        undef,
        undef,
        '2"',
        'qQ',
        undef,
      ],
      '2' => [
        '1!',
        undef,
        undef,
        '33',
        'wW',
        'qQ',
      ],
      '3' => [
        '2"',
        undef,
        undef,
        '4$',
        'eE',
        'wW',
      ],
      '4' => [
        '33',
        undef,
        undef,
        '5%',
        'rR',
        'eE',
      ],
      '5' => [
        '4$',
        undef,
        undef,
        '6&',
        'tT',
        'rR',
      ],
      '6' => [
        '5%',
        undef,
        undef,
        '7/',
        'zZ',
        'tT',
      ],
      '7' => [
        '6&',
        undef,
        undef,
        '8(',
        'uU',
        'zZ',
      ],
      '8' => [
        '7/',
        undef,
        undef,
        '9)',
        'iI',
        'uU',
      ],
      '9' => [
        '8(',
        undef,
        undef,
        '0=',
        'oO',
        'iI',
      ],
      ':' => [
        ',;',
        'lL',
        'oO',
        '-_',
        undef,
        undef,
      ],
      ';' => [
        'mM',
        'kK',
        'lL',
        '.:',
        undef,
        undef,
      ],
      '<' => [
        undef,
        undef,
        'aA',
        'yY',
        undef,
        undef,
      ],
      '=' => [
        '9)',
        undef,
        undef,
        '\\?',
        'pP',
        'oO',
      ],
      '>' => [
        undef,
        undef,
        'aA',
        'yY',
        undef,
        undef,
      ],
      '?' => [
        '0=',
        undef,
        undef,
        '`\'',
        undef,
        'pP',
      ],
      'A' => [
        undef,
        'qQ',
        'wW',
        'sS',
        'yY',
        '<>',
      ],
      'B' => [
        'vV',
        'gG',
        'hH',
        'nN',
        undef,
        undef,
      ],
      'C' => [
        'xX',
        'dD',
        'fF',
        'vV',
        undef,
        undef,
      ],
      'D' => [
        'sS',
        'eE',
        'rR',
        'fF',
        'cC',
        'xX',
      ],
      'E' => [
        'wW',
        '33',
        '4$',
        'rR',
        'dD',
        'sS',
      ],
      'F' => [
        'dD',
        'rR',
        'tT',
        'gG',
        'vV',
        'cC',
      ],
      'G' => [
        'fF',
        'tT',
        'zZ',
        'hH',
        'bB',
        'vV',
      ],
      'H' => [
        'gG',
        'zZ',
        'uU',
        'jJ',
        'nN',
        'bB',
      ],
      'I' => [
        'uU',
        '8(',
        '9)',
        'oO',
        'kK',
        'jJ',
      ],
      'J' => [
        'hH',
        'uU',
        'iI',
        'kK',
        'mM',
        'nN',
      ],
      'K' => [
        'jJ',
        'iI',
        'oO',
        'lL',
        ',;',
        'mM',
      ],
      'L' => [
        'kK',
        'oO',
        'pP',
        'oO',
        '.:',
        ',;',
      ],
      'M' => [
        'nN',
        'jJ',
        'kK',
        ',;',
        undef,
        undef,
      ],
      'N' => [
        'bB',
        'hH',
        'jJ',
        'mM',
        undef,
        undef,
      ],
      'O' => [
        'lL',
        'pP',
        undef,
        undef,
        '-_',
        '.:',
        'iI',
        '9)',
        '0=',
        'pP',
        'lL',
        'kK',
      ],
      'P' => [
        'oO',
        '0=',
        '\\?',
        undef,
        'oO',
        'lL',
      ],
      'Q' => [
        undef,
        '1!',
        '2"',
        'wW',
        'aA',
        undef,
      ],
      'R' => [
        'eE',
        '4$',
        '5%',
        'tT',
        'fF',
        'dD',
      ],
      'S' => [
        'aA',
        'wW',
        'eE',
        'dD',
        'xX',
        'yY',
      ],
      'T' => [
        'rR',
        '5%',
        '6&',
        'zZ',
        'gG',
        'fF',
      ],
      'U' => [
        'zZ',
        '7/',
        '8(',
        'iI',
        'jJ',
        'hH',
      ],
      'V' => [
        'cC',
        'fF',
        'gG',
        'bB',
        undef,
        undef,
      ],
      'W' => [
        'qQ',
        '2"',
        '33',
        'eE',
        'sS',
        'aA',
      ],
      'X' => [
        'yY',
        'sS',
        'dD',
        'cC',
        undef,
        undef,
      ],
      'Y' => [
        '<>',
        'aA',
        'sS',
        'xX',
        undef,
        undef,
      ],
      'Z' => [
        'tT',
        '6&',
        '7/',
        'uU',
        'hH',
        'gG',
      ],
      '\\' => [
        '0=',
        undef,
        undef,
        '`\'',
        undef,
        'pP',
      ],
      '^' => [
        undef,
        undef,
        undef,
        '1!',
        undef,
        undef,
      ],
      '_' => [
        '.:',
        'oO',
        undef,
        undef,
        undef,
        undef,
      ],
      '`' => [
        '\\?',
        undef,
        undef,
        undef,
        '+*',
        undef,
      ],
      'a' => [
        undef,
        'qQ',
        'wW',
        'sS',
        'yY',
        '<>',
      ],
      'b' => [
        'vV',
        'gG',
        'hH',
        'nN',
        undef,
        undef,
      ],
      'c' => [
        'xX',
        'dD',
        'fF',
        'vV',
        undef,
        undef,
      ],
      'd' => [
        'sS',
        'eE',
        'rR',
        'fF',
        'cC',
        'xX',
      ],
      'e' => [
        'wW',
        '33',
        '4$',
        'rR',
        'dD',
        'sS',
      ],
      'f' => [
        'dD',
        'rR',
        'tT',
        'gG',
        'vV',
        'cC',
      ],
      'g' => [
        'fF',
        'tT',
        'zZ',
        'hH',
        'bB',
        'vV',
      ],
      'h' => [
        'gG',
        'zZ',
        'uU',
        'jJ',
        'nN',
        'bB',
      ],
      'i' => [
        'uU',
        '8(',
        '9)',
        'oO',
        'kK',
        'jJ',
      ],
      'j' => [
        'hH',
        'uU',
        'iI',
        'kK',
        'mM',
        'nN',
      ],
      'k' => [
        'jJ',
        'iI',
        'oO',
        'lL',
        ',;',
        'mM',
      ],
      'l' => [
        'kK',
        'oO',
        'pP',
        'oO',
        '.:',
        ',;',
      ],
      'm' => [
        'nN',
        'jJ',
        'kK',
        ',;',
        undef,
        undef,
      ],
      'n' => [
        'bB',
        'hH',
        'jJ',
        'mM',
        undef,
        undef,
      ],
      'o' => [
        'lL',
        'pP',
        undef,
        undef,
        '-_',
        '.:',
        'iI',
        '9)',
        '0=',
        'pP',
        'lL',
        'kK',
      ],
      'p' => [
        'oO',
        '0=',
        '\\?',
        undef,
        'oO',
        'lL',
      ],
      'q' => [
        undef,
        '1!',
        '2"',
        'wW',
        'aA',
        undef,
      ],
      'r' => [
        'eE',
        '4$',
        '5%',
        'tT',
        'fF',
        'dD',
      ],
      's' => [
        'aA',
        'wW',
        'eE',
        'dD',
        'xX',
        'yY',
      ],
      't' => [
        'rR',
        '5%',
        '6&',
        'zZ',
        'gG',
        'fF',
      ],
      'u' => [
        'zZ',
        '7/',
        '8(',
        'iI',
        'jJ',
        'hH',
      ],
      'v' => [
        'cC',
        'fF',
        'gG',
        'bB',
        undef,
        undef,
      ],
      'w' => [
        'qQ',
        '2"',
        '33',
        'eE',
        'sS',
        'aA',
      ],
      'x' => [
        'yY',
        'sS',
        'dD',
        'cC',
        undef,
        undef,
      ],
      'y' => [
        '<>',
        'aA',
        'sS',
        'xX',
        undef,
        undef,
      ],
      'z' => [
        'tT',
        '6&',
        '7/',
        'uU',
        'hH',
        'gG',
      ],
    },
    'starting_positions' => 87,
  },
)
;

1;
